@@ -1,7 +1,7 @@
 from .builtin import Command, CommandHelp, CommandPrivacy, CommandSettings, CommandStart, ContentTypeFilter, \
     ExceptionsFilter, HashTag, Regexp, RegexpCommandsFilter, StateFilter, \
     Text, IDFilter, AdminFilter, IsReplyFilter, IsSenderContact, ForwardedMessageFilter, \
-    ChatTypeFilter
+    ChatTypeFilter, MediaGroupFilter
 from .factory import FiltersFactory
 from .filters import AbstractFilter, BoundFilter, Filter, FilterNotPassed, FilterRecord, execute_filter, \
     check_filters, get_filter_spec, get_filters_spec
@@ -25,6 +25,7 @@ __all__ = (
     'IsSenderContact',
     'ForwardedMessageFilter',
     'ChatTypeFilter',
+    'MediaGroupFilter',
     'FiltersFactory',
     'AbstractFilter',
     'BoundFilter',
